var ViewVariants = function()
{
	var vgt = {};
	var debug = 0;
	
	vgt.initPage = function()
	{
		Buttons.addClickHandler('close', App.closeWindow);
		
		var url = '../VariantCalling.servlet?ID='+App.getSessionId();
		url += '&cmd=GetVcfStatistics';
		url += '&fileId='+Data.int('page-data', 'file-id');
		url += '&itemId='+Data.int('page-data', 'item-id');
		
		Wizard.showLoadingAnimation('Loading VCF file...');
		Wizard.asyncJsonRequest(url, vgt.onFilesLoaded);
	}
	
	vgt.onFilesLoaded = function(response)
	{
		var rba = response.rawbioassay;
		var snpData = response.snpData;
		
		var numIns = 0;
		var numDel = 0;
		var numSnv = 0;
		
		var html = '';
		for (var snpNo = 0; snpNo < snpData.length; snpNo++)
		{
			var snp = snpData[snpNo];
			var info = snp.info;
			var cosmicId = info['cosmic_ID'];
			var dbSnpId = info['dbsnp_ID'];
			var type = info['TYPE'];
			if (type == 'SNV') numSnv++;
			else if (type == 'Insertion') numIns++;
			else if (type == 'Deletion') numDel++;
			html += '<tr class="snp highlight">';
			html += '<td>'+Strings.encodeTags(snp.chromosome+':'+snp.position)+'</td>';
			html += '<td class="dottedleft ref">'+vgt.getRefAndAlt(snp.ref, snp.alt)+'</td>';
			html += '<td class="dottedleft">'+Strings.encodeTags(type)+'</td>';
			html += '<td class="dottedleft">'+vgt.getGenes(info['ncbiRefSeq'])+'</td>';
			html += '<td class="dottedleft">'+vgt.getCosmicLink(cosmicId)+'</td>';
			html += '<td class="dottedleft">'+vgt.getDbSnpLink(dbSnpId)+'</td>';
			html += '</tr>';
		}
		Doc.element('snp-list').innerHTML = html;
		Doc.show('snp-table', 'table');
		Doc.element('snp-count').innerHTML = snpData.length + ' passed filter ('+
			numSnv + ' SNV; ' + numIns + ' insertions; ' + numDel + ' deletions); ' +
			rba.VariantsRaw + ' raw variants';
	}
	
	vgt.getAnnValues = function(info, key)
	{
		var list = [];
		var numAnnEntries = info['ANN#'];
		for (var i = 0; i < numAnnEntries; i++)
		{
			var val = info['ANN.'+key+'['+i+']'];
			if (val) list[list.length] = val;
		}
		
		return Strings.encodeTags(list.join(', '));
	}
	
	vgt.getGenes = function(genes)
	{
		if (!genes) return '';
		return Strings.encodeTags(genes.split(',').join(', '));
	}
	
	vgt.getRefAndAlt = function(ref, alt)
	{
		if (ref.length > 6) ref = '<span title="'+ref+'">'+ref.substring(0, 5)+'...</span>';
		if (alt.length > 6) alt = '<span title="'+alt+'">'+alt.substring(0, 5)+'...</span>';
		return ref + ' › ' + alt;
	}
	
	vgt.getCosmicLink = function(cosmicId)
	{
		if (!cosmicId) return '';

		var tmp = cosmicId.split(',');
		var links = [];
		for (var i = 0; i < tmp.length; i++)
		{
			var link = '<a target="_blank" title="View in COSMIC (new window)"';
			link += ' href="https://cancer.sanger.ac.uk/cosmic/search?q='+encodeURIComponent(tmp[i])+'">';
			link += Strings.encodeTags(tmp[i])+'</a>';
			
			links[i] = link;
		}
		return links.join(', ');
	}
	
	vgt.getDbSnpLink = function(rsId)
	{
		if (!rsId) return '';

		var tmp = rsId.split(',');
		var links = [];
		for (var i = 0; i < tmp.length; i++)
		{
			var link = '<a target="_blank" title="View in dbSNP (new window)"';
			link += ' href="https://www.ncbi.nlm.nih.gov/snp/'+encodeURIComponent(tmp[i])+'">';
			link += Strings.encodeTags(tmp[i])+'</a>';
			
			links[i] = link;
		}
		return links.join(', ');
	}
	
	return vgt;
}();

Doc.onLoad(ViewVariants.initPage);
